#ifdef E_TYPEDEFS
#else
#ifndef E_INT_CONFIG_COLOR_CLASSES_H
#define E_INT_CONFIG_COLOR_CLASSES_H

E_Config_Dialog *e_int_config_color_classes(E_Container *con, const char *params __UNUSED__);

#endif
#endif
